==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
var DataLegendSummaryEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryEventArgsDescriptionMetadata, _super);
    function DataLegendSummaryEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
            DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataLegendSummaryEventArgsDescriptionMetadata.a);
    };
    DataLegendSummaryEventArgsDescriptionMetadata.c = function (a) {
        a.item("ColumnValues", "Array:double");
        a.item("ColumnMemberPath", "String");
        a.item("SummaryValue", "Number:double");
        a.item("SummaryUnits", "String");
        a.item("SummaryLabel", "String");
    };
    DataLegendSummaryEventArgsDescriptionMetadata.d = function (a) {
        DataLegendSummaryEventArgsDescriptionMetadata.b(a);
        a.u("DataLegendSummaryEventArgs", function () { return new DataLegendSummaryEventArgsDescription(); });
        a.t("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
    };
    DataLegendSummaryEventArgsDescriptionMetadata.$t = markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
}(Base));
export { DataLegendSummaryEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
var DataLegendSummaryEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendSummaryEventArgsDescriptionMetadata, _super);
    function DataLegendSummaryEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
            DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataLegendSummaryEventArgsDescriptionMetadata.a);
    };
    DataLegendSummaryEventArgsDescriptionMetadata.c = function (a) {
        a.item("ColumnValues", "Array:double");
        a.item("ColumnMemberPath", "String");
        a.item("SummaryValue", "Number:double");
        a.item("SummaryUnits", "String");
        a.item("SummaryLabel", "String");
    };
    DataLegendSummaryEventArgsDescriptionMetadata.d = function (a) {
        DataLegendSummaryEventArgsDescriptionMetadata.b(a);
        a.aa("DataLegendSummaryEventArgs", function () { return new DataLegendSummaryEventArgsDescription(); });
        a.z("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
    };
    DataLegendSummaryEventArgsDescriptionMetadata.$t = markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
}(Base));
export { DataLegendSummaryEventArgsDescriptionMetadata };
